# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/credential.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/api/v1alpha/credential.proto',
  package='kaskada.api.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\027com.kaskada.api.v1alphaP\001Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$kaskada/api/v1alpha/credential.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a kaskada/api/v1alpha/shared.proto\"\x16\n\x14GetCredentialRequest\"\xa7\x01\n\x15GetCredentialResponse\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12#\n\rclient_secret\x18\x02 \x01(\tR\x0c\x63lientSecret\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails2\x8e\x01\n\x11\x43redentialService\x12y\n\x03Get\x12).kaskada.api.v1alpha.GetCredentialRequest\x1a*.kaskada.api.v1alpha.GetCredentialResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1alpha/credentialBV\n\x17\x63om.kaskada.api.v1alphaP\x01Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alphab\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,kaskada_dot_api_dot_v1alpha_dot_shared__pb2.DESCRIPTOR,])




_GETCREDENTIALREQUEST = _descriptor.Descriptor(
  name='GetCredentialRequest',
  full_name='kaskada.api.v1alpha.GetCredentialRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=147,
)


_GETCREDENTIALRESPONSE = _descriptor.Descriptor(
  name='GetCredentialResponse',
  full_name='kaskada.api.v1alpha.GetCredentialResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='kaskada.api.v1alpha.GetCredentialResponse.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clientId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_secret', full_name='kaskada.api.v1alpha.GetCredentialResponse.client_secret', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clientSecret', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.GetCredentialResponse.request_details', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=150,
  serialized_end=317,
)

_GETCREDENTIALRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
DESCRIPTOR.message_types_by_name['GetCredentialRequest'] = _GETCREDENTIALREQUEST
DESCRIPTOR.message_types_by_name['GetCredentialResponse'] = _GETCREDENTIALRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCredentialRequest = _reflection.GeneratedProtocolMessageType('GetCredentialRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCREDENTIALREQUEST,
  '__module__' : 'kaskada.api.v1alpha.credential_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetCredentialRequest)
  })
_sym_db.RegisterMessage(GetCredentialRequest)

GetCredentialResponse = _reflection.GeneratedProtocolMessageType('GetCredentialResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCREDENTIALRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.credential_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetCredentialResponse)
  })
_sym_db.RegisterMessage(GetCredentialResponse)


DESCRIPTOR._options = None

_CREDENTIALSERVICE = _descriptor.ServiceDescriptor(
  name='CredentialService',
  full_name='kaskada.api.v1alpha.CredentialService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=320,
  serialized_end=462,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='kaskada.api.v1alpha.CredentialService.Get',
    index=0,
    containing_service=None,
    input_type=_GETCREDENTIALREQUEST,
    output_type=_GETCREDENTIALRESPONSE,
    serialized_options=b'\202\323\344\223\002\025\022\023/v1alpha/credential',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CREDENTIALSERVICE)

DESCRIPTOR.services_by_name['CredentialService'] = _CREDENTIALSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/materialization.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaskada.api.v1alpha import compute_pb2 as kaskada_dot_api_dot_v1alpha_dot_compute__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2
from kaskada.fenl.v1alpha import schema_pb2 as kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2
from kaskada.prepare.v1alpha import slice_pb2 as kaskada_dot_prepare_dot_v1alpha_dot_slice__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/api/v1alpha/materialization.proto',
  package='kaskada.api.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\027com.kaskada.api.v1alphaP\001Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)kaskada/api/v1alpha/materialization.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!kaskada/api/v1alpha/compute.proto\x1a kaskada/api/v1alpha/shared.proto\x1a!kaskada/fenl/v1alpha/schema.proto\x1a#kaskada/prepare/v1alpha/slice.proto\x1a\x17validate/validate.proto\"\xd1\x04\n\x0fMaterialization\x12\x33\n\x12materialization_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x11materializationId\x12:\n\x14materialization_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13materializationName\x12\x41\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x14\n\x05query\x18\x04 \x01(\tR\x05query\x12<\n\nwith_views\x18\x05 \x03(\x0b\x32\x1d.kaskada.api.v1alpha.WithViewR\twithViews\x12J\n\tredis_a_i\x18\x06 \x01(\x0b\x32,.kaskada.api.v1alpha.Materialization.RedisAIH\x00R\x07redisAI\x12:\n\x06schema\x18\x07 \x01(\x0b\x32\x1c.kaskada.fenl.v1alpha.SchemaB\x04\xe2\x41\x01\x03R\x06schema\x12;\n\x05slice\x18\x08 \x01(\x0b\x32%.kaskada.prepare.v1alpha.SliceRequestR\x05slice\x1a\x62\n\x07RedisAI\x12\x19\n\x02\x64\x62\x18\x01 \x01(\x05\x42\t\xfa\x42\x06\x1a\x04\x18\x0f(\x00R\x02\x64\x62\x12\x1b\n\x04host\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04host\x12\x1f\n\x04port\x18\x03 \x01(\x05\x42\x0b\xfa\x42\x08\x1a\x06\x18\xff\xff\x03 \x00R\x04portB\r\n\x0b\x64\x65stination\"}\n\x1bListMaterializationsRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\'\n\tpage_size\x18\x02 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xe6\x01\n\x1cListMaterializationsResponse\x12P\n\x10materializations\x18\x01 \x03(\x0b\x32$.kaskada.api.v1alpha.MaterializationR\x10materializations\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"W\n\x19GetMaterializationRequest\x12:\n\x14materialization_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13materializationName\"\xba\x01\n\x1aGetMaterializationResponse\x12N\n\x0fmaterialization\x18\x01 \x01(\x0b\x32$.kaskada.api.v1alpha.MaterializationR\x0fmaterialization\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"n\n\x1c\x43reateMaterializationRequest\x12N\n\x0fmaterialization\x18\x01 \x01(\x0b\x32$.kaskada.api.v1alpha.MaterializationR\x0fmaterialization\"\xf8\x01\n\x1d\x43reateMaterializationResponse\x12N\n\x0fmaterialization\x18\x01 \x01(\x0b\x32$.kaskada.api.v1alpha.MaterializationR\x0fmaterialization\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\x12\x39\n\x08\x61nalysis\x18\x03 \x01(\x0b\x32\x1d.kaskada.api.v1alpha.AnalysisR\x08\x61nalysis\"Z\n\x1c\x44\x65leteMaterializationRequest\x12:\n\x14materialization_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13materializationName\"s\n\x1d\x44\x65leteMaterializationResponse\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetailsJ\x04\x08\x01\x10\x02\x32\xdf\x05\n\x16MaterializationService\x12\x9e\x01\n\x14ListMaterializations\x12\x30.kaskada.api.v1alpha.ListMaterializationsRequest\x1a\x31.kaskada.api.v1alpha.ListMaterializationsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1alpha/materializations\x12\xb1\x01\n\x12GetMaterialization\x12..kaskada.api.v1alpha.GetMaterializationRequest\x1a/.kaskada.api.v1alpha.GetMaterializationResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/v1alpha/materializations/{materialization_name=*}\x12\xb2\x01\n\x15\x43reateMaterialization\x12\x31.kaskada.api.v1alpha.CreateMaterializationRequest\x1a\x32.kaskada.api.v1alpha.CreateMaterializationResponse\"2\x82\xd3\xe4\x93\x02,\"\x19/v1alpha/materializations:\x0fmaterialization\x12\xba\x01\n\x15\x44\x65leteMaterialization\x12\x31.kaskada.api.v1alpha.DeleteMaterializationRequest\x1a\x32.kaskada.api.v1alpha.DeleteMaterializationResponse\":\x82\xd3\xe4\x93\x02\x34*2/v1alpha/materializations/{materialization_name=*}BV\n\x17\x63om.kaskada.api.v1alphaP\x01Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alphab\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,kaskada_dot_api_dot_v1alpha_dot_compute__pb2.DESCRIPTOR,kaskada_dot_api_dot_v1alpha_dot_shared__pb2.DESCRIPTOR,kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2.DESCRIPTOR,kaskada_dot_prepare_dot_v1alpha_dot_slice__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_MATERIALIZATION_REDISAI = _descriptor.Descriptor(
  name='RedisAI',
  full_name='kaskada.api.v1alpha.Materialization.RedisAI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='db', full_name='kaskada.api.v1alpha.Materialization.RedisAI.db', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006\032\004\030\017(\000', json_name='db', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='kaskada.api.v1alpha.Materialization.RedisAI.host', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='host', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='kaskada.api.v1alpha.Materialization.RedisAI.port', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010\032\006\030\377\377\003 \000', json_name='port', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=809,
  serialized_end=907,
)

_MATERIALIZATION = _descriptor.Descriptor(
  name='Materialization',
  full_name='kaskada.api.v1alpha.Materialization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='materialization_id', full_name='kaskada.api.v1alpha.Materialization.materialization_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='materializationId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='materialization_name', full_name='kaskada.api.v1alpha.Materialization.materialization_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='materializationName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='kaskada.api.v1alpha.Materialization.create_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='createTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='kaskada.api.v1alpha.Materialization.query', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_views', full_name='kaskada.api.v1alpha.Materialization.with_views', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='withViews', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redis_a_i', full_name='kaskada.api.v1alpha.Materialization.redis_a_i', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='redisAI', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='kaskada.api.v1alpha.Materialization.schema', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='schema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slice', full_name='kaskada.api.v1alpha.Materialization.slice', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='slice', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MATERIALIZATION_REDISAI, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='destination', full_name='kaskada.api.v1alpha.Materialization.destination',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=329,
  serialized_end=922,
)


_LISTMATERIALIZATIONSREQUEST = _descriptor.Descriptor(
  name='ListMaterializationsRequest',
  full_name='kaskada.api.v1alpha.ListMaterializationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='search', full_name='kaskada.api.v1alpha.ListMaterializationsRequest.search', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='search', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='kaskada.api.v1alpha.ListMaterializationsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\032\005\030\350\007(\000', json_name='pageSize', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='kaskada.api.v1alpha.ListMaterializationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pageToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=924,
  serialized_end=1049,
)


_LISTMATERIALIZATIONSRESPONSE = _descriptor.Descriptor(
  name='ListMaterializationsResponse',
  full_name='kaskada.api.v1alpha.ListMaterializationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='materializations', full_name='kaskada.api.v1alpha.ListMaterializationsResponse.materializations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materializations', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='kaskada.api.v1alpha.ListMaterializationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nextPageToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.ListMaterializationsResponse.request_details', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1052,
  serialized_end=1282,
)


_GETMATERIALIZATIONREQUEST = _descriptor.Descriptor(
  name='GetMaterializationRequest',
  full_name='kaskada.api.v1alpha.GetMaterializationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='materialization_name', full_name='kaskada.api.v1alpha.GetMaterializationRequest.materialization_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='materializationName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1284,
  serialized_end=1371,
)


_GETMATERIALIZATIONRESPONSE = _descriptor.Descriptor(
  name='GetMaterializationResponse',
  full_name='kaskada.api.v1alpha.GetMaterializationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='materialization', full_name='kaskada.api.v1alpha.GetMaterializationResponse.materialization', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materialization', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.GetMaterializationResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1374,
  serialized_end=1560,
)


_CREATEMATERIALIZATIONREQUEST = _descriptor.Descriptor(
  name='CreateMaterializationRequest',
  full_name='kaskada.api.v1alpha.CreateMaterializationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='materialization', full_name='kaskada.api.v1alpha.CreateMaterializationRequest.materialization', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materialization', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1562,
  serialized_end=1672,
)


_CREATEMATERIALIZATIONRESPONSE = _descriptor.Descriptor(
  name='CreateMaterializationResponse',
  full_name='kaskada.api.v1alpha.CreateMaterializationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='materialization', full_name='kaskada.api.v1alpha.CreateMaterializationResponse.materialization', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materialization', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.CreateMaterializationResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='analysis', full_name='kaskada.api.v1alpha.CreateMaterializationResponse.analysis', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='analysis', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1675,
  serialized_end=1923,
)


_DELETEMATERIALIZATIONREQUEST = _descriptor.Descriptor(
  name='DeleteMaterializationRequest',
  full_name='kaskada.api.v1alpha.DeleteMaterializationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='materialization_name', full_name='kaskada.api.v1alpha.DeleteMaterializationRequest.materialization_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='materializationName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1925,
  serialized_end=2015,
)


_DELETEMATERIALIZATIONRESPONSE = _descriptor.Descriptor(
  name='DeleteMaterializationResponse',
  full_name='kaskada.api.v1alpha.DeleteMaterializationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.DeleteMaterializationResponse.request_details', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2017,
  serialized_end=2132,
)

_MATERIALIZATION_REDISAI.containing_type = _MATERIALIZATION
_MATERIALIZATION.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MATERIALIZATION.fields_by_name['with_views'].message_type = kaskada_dot_api_dot_v1alpha_dot_compute__pb2._WITHVIEW
_MATERIALIZATION.fields_by_name['redis_a_i'].message_type = _MATERIALIZATION_REDISAI
_MATERIALIZATION.fields_by_name['schema'].message_type = kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2._SCHEMA
_MATERIALIZATION.fields_by_name['slice'].message_type = kaskada_dot_prepare_dot_v1alpha_dot_slice__pb2._SLICEREQUEST
_MATERIALIZATION.oneofs_by_name['destination'].fields.append(
  _MATERIALIZATION.fields_by_name['redis_a_i'])
_MATERIALIZATION.fields_by_name['redis_a_i'].containing_oneof = _MATERIALIZATION.oneofs_by_name['destination']
_LISTMATERIALIZATIONSRESPONSE.fields_by_name['materializations'].message_type = _MATERIALIZATION
_LISTMATERIALIZATIONSRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_GETMATERIALIZATIONRESPONSE.fields_by_name['materialization'].message_type = _MATERIALIZATION
_GETMATERIALIZATIONRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_CREATEMATERIALIZATIONREQUEST.fields_by_name['materialization'].message_type = _MATERIALIZATION
_CREATEMATERIALIZATIONRESPONSE.fields_by_name['materialization'].message_type = _MATERIALIZATION
_CREATEMATERIALIZATIONRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_CREATEMATERIALIZATIONRESPONSE.fields_by_name['analysis'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._ANALYSIS
_DELETEMATERIALIZATIONRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
DESCRIPTOR.message_types_by_name['Materialization'] = _MATERIALIZATION
DESCRIPTOR.message_types_by_name['ListMaterializationsRequest'] = _LISTMATERIALIZATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListMaterializationsResponse'] = _LISTMATERIALIZATIONSRESPONSE
DESCRIPTOR.message_types_by_name['GetMaterializationRequest'] = _GETMATERIALIZATIONREQUEST
DESCRIPTOR.message_types_by_name['GetMaterializationResponse'] = _GETMATERIALIZATIONRESPONSE
DESCRIPTOR.message_types_by_name['CreateMaterializationRequest'] = _CREATEMATERIALIZATIONREQUEST
DESCRIPTOR.message_types_by_name['CreateMaterializationResponse'] = _CREATEMATERIALIZATIONRESPONSE
DESCRIPTOR.message_types_by_name['DeleteMaterializationRequest'] = _DELETEMATERIALIZATIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteMaterializationResponse'] = _DELETEMATERIALIZATIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Materialization = _reflection.GeneratedProtocolMessageType('Materialization', (_message.Message,), {

  'RedisAI' : _reflection.GeneratedProtocolMessageType('RedisAI', (_message.Message,), {
    'DESCRIPTOR' : _MATERIALIZATION_REDISAI,
    '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Materialization.RedisAI)
    })
  ,
  'DESCRIPTOR' : _MATERIALIZATION,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Materialization)
  })
_sym_db.RegisterMessage(Materialization)
_sym_db.RegisterMessage(Materialization.RedisAI)

ListMaterializationsRequest = _reflection.GeneratedProtocolMessageType('ListMaterializationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMATERIALIZATIONSREQUEST,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListMaterializationsRequest)
  })
_sym_db.RegisterMessage(ListMaterializationsRequest)

ListMaterializationsResponse = _reflection.GeneratedProtocolMessageType('ListMaterializationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMATERIALIZATIONSRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListMaterializationsResponse)
  })
_sym_db.RegisterMessage(ListMaterializationsResponse)

GetMaterializationRequest = _reflection.GeneratedProtocolMessageType('GetMaterializationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMATERIALIZATIONREQUEST,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetMaterializationRequest)
  })
_sym_db.RegisterMessage(GetMaterializationRequest)

GetMaterializationResponse = _reflection.GeneratedProtocolMessageType('GetMaterializationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMATERIALIZATIONRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetMaterializationResponse)
  })
_sym_db.RegisterMessage(GetMaterializationResponse)

CreateMaterializationRequest = _reflection.GeneratedProtocolMessageType('CreateMaterializationRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMATERIALIZATIONREQUEST,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateMaterializationRequest)
  })
_sym_db.RegisterMessage(CreateMaterializationRequest)

CreateMaterializationResponse = _reflection.GeneratedProtocolMessageType('CreateMaterializationResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMATERIALIZATIONRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateMaterializationResponse)
  })
_sym_db.RegisterMessage(CreateMaterializationResponse)

DeleteMaterializationRequest = _reflection.GeneratedProtocolMessageType('DeleteMaterializationRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMATERIALIZATIONREQUEST,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteMaterializationRequest)
  })
_sym_db.RegisterMessage(DeleteMaterializationRequest)

DeleteMaterializationResponse = _reflection.GeneratedProtocolMessageType('DeleteMaterializationResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMATERIALIZATIONRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteMaterializationResponse)
  })
_sym_db.RegisterMessage(DeleteMaterializationResponse)


DESCRIPTOR._options = None
_MATERIALIZATION_REDISAI.fields_by_name['db']._options = None
_MATERIALIZATION_REDISAI.fields_by_name['host']._options = None
_MATERIALIZATION_REDISAI.fields_by_name['port']._options = None
_MATERIALIZATION.fields_by_name['materialization_id']._options = None
_MATERIALIZATION.fields_by_name['materialization_name']._options = None
_MATERIALIZATION.fields_by_name['create_time']._options = None
_MATERIALIZATION.fields_by_name['schema']._options = None
_LISTMATERIALIZATIONSREQUEST.fields_by_name['page_size']._options = None
_GETMATERIALIZATIONREQUEST.fields_by_name['materialization_name']._options = None
_DELETEMATERIALIZATIONREQUEST.fields_by_name['materialization_name']._options = None

_MATERIALIZATIONSERVICE = _descriptor.ServiceDescriptor(
  name='MaterializationService',
  full_name='kaskada.api.v1alpha.MaterializationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2135,
  serialized_end=2870,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListMaterializations',
    full_name='kaskada.api.v1alpha.MaterializationService.ListMaterializations',
    index=0,
    containing_service=None,
    input_type=_LISTMATERIALIZATIONSREQUEST,
    output_type=_LISTMATERIALIZATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/v1alpha/materializations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMaterialization',
    full_name='kaskada.api.v1alpha.MaterializationService.GetMaterialization',
    index=1,
    containing_service=None,
    input_type=_GETMATERIALIZATIONREQUEST,
    output_type=_GETMATERIALIZATIONRESPONSE,
    serialized_options=b'\202\323\344\223\0024\0222/v1alpha/materializations/{materialization_name=*}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateMaterialization',
    full_name='kaskada.api.v1alpha.MaterializationService.CreateMaterialization',
    index=2,
    containing_service=None,
    input_type=_CREATEMATERIALIZATIONREQUEST,
    output_type=_CREATEMATERIALIZATIONRESPONSE,
    serialized_options=b'\202\323\344\223\002,\"\031/v1alpha/materializations:\017materialization',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteMaterialization',
    full_name='kaskada.api.v1alpha.MaterializationService.DeleteMaterialization',
    index=3,
    containing_service=None,
    input_type=_DELETEMATERIALIZATIONREQUEST,
    output_type=_DELETEMATERIALIZATIONRESPONSE,
    serialized_options=b'\202\323\344\223\0024*2/v1alpha/materializations/{materialization_name=*}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MATERIALIZATIONSERVICE)

DESCRIPTOR.services_by_name['MaterializationService'] = _MATERIALIZATIONSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/shared.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaskada.errdetails.v1alpha import fenl_diagnostics_pb2 as kaskada_dot_errdetails_dot_v1alpha_dot_fenl__diagnostics__pb2
from kaskada.fenl.v1alpha import schema_pb2 as kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/api/v1alpha/shared.proto',
  package='kaskada.api.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\027com.kaskada.api.v1alphaP\001Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n kaskada/api/v1alpha/shared.proto\x12\x13kaskada.api.v1alpha\x1a\x31kaskada/errdetails/v1alpha/fenl_diagnostics.proto\x1a!kaskada/fenl/v1alpha/schema.proto\x1a\x17validate/validate.proto\"\xa8\x01\n\x08\x41nalysis\x12#\n\rmissing_names\x18\x01 \x03(\tR\x0cmissingNames\x12V\n\x10\x66\x65nl_diagnostics\x18\x02 \x01(\x0b\x32+.kaskada.errdetails.v1alpha.FenlDiagnosticsR\x0f\x66\x65nlDiagnostics\x12\x1f\n\x0b\x63\x61n_execute\x18\x03 \x01(\x08R\ncanExecute\"\xee\x01\n\rAWSCredential\x12M\n\naccess_key\x18\x01 \x01(\x0b\x32,.kaskada.api.v1alpha.AWSCredential.AccessKeyH\x00R\taccessKey\x1a{\n\tAccessKey\x12\x32\n\x11\x61ws_access_key_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0e\x61wsAccessKeyId\x12:\n\x15\x61ws_secret_access_key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x12\x61wsSecretAccessKeyB\x11\n\ncredential\x12\x03\xf8\x42\x01\"\xfc\x02\n\x0e\x45xternalS3File\x12;\n\x14virtual_hosted_style\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00R\x12virtualHostedStyle\x12\x61\n\x11\x62ucket_region_key\x18\x02 \x01(\x0b\x32\x33.kaskada.api.v1alpha.ExternalS3File.BucketRegionKeyH\x00R\x0f\x62ucketRegionKey\x12I\n\x0e\x61ws_credential\x18\x10 \x01(\x0b\x32\".kaskada.api.v1alpha.AWSCredentialR\rawsCredential\x1an\n\x0f\x42ucketRegionKey\x12\x1f\n\x06\x62ucket\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06\x62ucket\x12\x1f\n\x06region\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06region\x12\x19\n\x03key\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x03keyB\x0f\n\x08location\x12\x03\xf8\x42\x01\"/\n\x0eRequestDetails\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\"P\n\x0bResumeToken\x12\"\n\rdata_token_id\x18\x01 \x01(\tR\x0b\x64\x61taTokenId\x12\x1d\n\nquery_hash\x18\x02 \x01(\x0cR\tqueryHashBV\n\x17\x63om.kaskada.api.v1alphaP\x01Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alphab\x06proto3'
  ,
  dependencies=[kaskada_dot_errdetails_dot_v1alpha_dot_fenl__diagnostics__pb2.DESCRIPTOR,kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_ANALYSIS = _descriptor.Descriptor(
  name='Analysis',
  full_name='kaskada.api.v1alpha.Analysis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='missing_names', full_name='kaskada.api.v1alpha.Analysis.missing_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='missingNames', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fenl_diagnostics', full_name='kaskada.api.v1alpha.Analysis.fenl_diagnostics', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fenlDiagnostics', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_execute', full_name='kaskada.api.v1alpha.Analysis.can_execute', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='canExecute', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=337,
)


_AWSCREDENTIAL_ACCESSKEY = _descriptor.Descriptor(
  name='AccessKey',
  full_name='kaskada.api.v1alpha.AWSCredential.AccessKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aws_access_key_id', full_name='kaskada.api.v1alpha.AWSCredential.AccessKey.aws_access_key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='awsAccessKeyId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aws_secret_access_key', full_name='kaskada.api.v1alpha.AWSCredential.AccessKey.aws_secret_access_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='awsSecretAccessKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=436,
  serialized_end=559,
)

_AWSCREDENTIAL = _descriptor.Descriptor(
  name='AWSCredential',
  full_name='kaskada.api.v1alpha.AWSCredential',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_key', full_name='kaskada.api.v1alpha.AWSCredential.access_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='accessKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_AWSCREDENTIAL_ACCESSKEY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='credential', full_name='kaskada.api.v1alpha.AWSCredential.credential',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=340,
  serialized_end=578,
)


_EXTERNALS3FILE_BUCKETREGIONKEY = _descriptor.Descriptor(
  name='BucketRegionKey',
  full_name='kaskada.api.v1alpha.ExternalS3File.BucketRegionKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='kaskada.api.v1alpha.ExternalS3File.BucketRegionKey.bucket', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='bucket', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='kaskada.api.v1alpha.ExternalS3File.BucketRegionKey.region', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='region', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='kaskada.api.v1alpha.ExternalS3File.BucketRegionKey.key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=834,
  serialized_end=944,
)

_EXTERNALS3FILE = _descriptor.Descriptor(
  name='ExternalS3File',
  full_name='kaskada.api.v1alpha.ExternalS3File',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='virtual_hosted_style', full_name='kaskada.api.v1alpha.ExternalS3File.virtual_hosted_style', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='virtualHostedStyle', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket_region_key', full_name='kaskada.api.v1alpha.ExternalS3File.bucket_region_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='bucketRegionKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aws_credential', full_name='kaskada.api.v1alpha.ExternalS3File.aws_credential', index=2,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='awsCredential', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXTERNALS3FILE_BUCKETREGIONKEY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='location', full_name='kaskada.api.v1alpha.ExternalS3File.location',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=581,
  serialized_end=961,
)


_REQUESTDETAILS = _descriptor.Descriptor(
  name='RequestDetails',
  full_name='kaskada.api.v1alpha.RequestDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='kaskada.api.v1alpha.RequestDetails.request_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1010,
)


_RESUMETOKEN = _descriptor.Descriptor(
  name='ResumeToken',
  full_name='kaskada.api.v1alpha.ResumeToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_token_id', full_name='kaskada.api.v1alpha.ResumeToken.data_token_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataTokenId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_hash', full_name='kaskada.api.v1alpha.ResumeToken.query_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='queryHash', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1012,
  serialized_end=1092,
)

_ANALYSIS.fields_by_name['fenl_diagnostics'].message_type = kaskada_dot_errdetails_dot_v1alpha_dot_fenl__diagnostics__pb2._FENLDIAGNOSTICS
_AWSCREDENTIAL_ACCESSKEY.containing_type = _AWSCREDENTIAL
_AWSCREDENTIAL.fields_by_name['access_key'].message_type = _AWSCREDENTIAL_ACCESSKEY
_AWSCREDENTIAL.oneofs_by_name['credential'].fields.append(
  _AWSCREDENTIAL.fields_by_name['access_key'])
_AWSCREDENTIAL.fields_by_name['access_key'].containing_oneof = _AWSCREDENTIAL.oneofs_by_name['credential']
_EXTERNALS3FILE_BUCKETREGIONKEY.containing_type = _EXTERNALS3FILE
_EXTERNALS3FILE.fields_by_name['bucket_region_key'].message_type = _EXTERNALS3FILE_BUCKETREGIONKEY
_EXTERNALS3FILE.fields_by_name['aws_credential'].message_type = _AWSCREDENTIAL
_EXTERNALS3FILE.oneofs_by_name['location'].fields.append(
  _EXTERNALS3FILE.fields_by_name['virtual_hosted_style'])
_EXTERNALS3FILE.fields_by_name['virtual_hosted_style'].containing_oneof = _EXTERNALS3FILE.oneofs_by_name['location']
_EXTERNALS3FILE.oneofs_by_name['location'].fields.append(
  _EXTERNALS3FILE.fields_by_name['bucket_region_key'])
_EXTERNALS3FILE.fields_by_name['bucket_region_key'].containing_oneof = _EXTERNALS3FILE.oneofs_by_name['location']
DESCRIPTOR.message_types_by_name['Analysis'] = _ANALYSIS
DESCRIPTOR.message_types_by_name['AWSCredential'] = _AWSCREDENTIAL
DESCRIPTOR.message_types_by_name['ExternalS3File'] = _EXTERNALS3FILE
DESCRIPTOR.message_types_by_name['RequestDetails'] = _REQUESTDETAILS
DESCRIPTOR.message_types_by_name['ResumeToken'] = _RESUMETOKEN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Analysis = _reflection.GeneratedProtocolMessageType('Analysis', (_message.Message,), {
  'DESCRIPTOR' : _ANALYSIS,
  '__module__' : 'kaskada.api.v1alpha.shared_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Analysis)
  })
_sym_db.RegisterMessage(Analysis)

AWSCredential = _reflection.GeneratedProtocolMessageType('AWSCredential', (_message.Message,), {

  'AccessKey' : _reflection.GeneratedProtocolMessageType('AccessKey', (_message.Message,), {
    'DESCRIPTOR' : _AWSCREDENTIAL_ACCESSKEY,
    '__module__' : 'kaskada.api.v1alpha.shared_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.AWSCredential.AccessKey)
    })
  ,
  'DESCRIPTOR' : _AWSCREDENTIAL,
  '__module__' : 'kaskada.api.v1alpha.shared_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.AWSCredential)
  })
_sym_db.RegisterMessage(AWSCredential)
_sym_db.RegisterMessage(AWSCredential.AccessKey)

ExternalS3File = _reflection.GeneratedProtocolMessageType('ExternalS3File', (_message.Message,), {

  'BucketRegionKey' : _reflection.GeneratedProtocolMessageType('BucketRegionKey', (_message.Message,), {
    'DESCRIPTOR' : _EXTERNALS3FILE_BUCKETREGIONKEY,
    '__module__' : 'kaskada.api.v1alpha.shared_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ExternalS3File.BucketRegionKey)
    })
  ,
  'DESCRIPTOR' : _EXTERNALS3FILE,
  '__module__' : 'kaskada.api.v1alpha.shared_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ExternalS3File)
  })
_sym_db.RegisterMessage(ExternalS3File)
_sym_db.RegisterMessage(ExternalS3File.BucketRegionKey)

RequestDetails = _reflection.GeneratedProtocolMessageType('RequestDetails', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTDETAILS,
  '__module__' : 'kaskada.api.v1alpha.shared_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.RequestDetails)
  })
_sym_db.RegisterMessage(RequestDetails)

ResumeToken = _reflection.GeneratedProtocolMessageType('ResumeToken', (_message.Message,), {
  'DESCRIPTOR' : _RESUMETOKEN,
  '__module__' : 'kaskada.api.v1alpha.shared_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ResumeToken)
  })
_sym_db.RegisterMessage(ResumeToken)


DESCRIPTOR._options = None
_AWSCREDENTIAL_ACCESSKEY.fields_by_name['aws_access_key_id']._options = None
_AWSCREDENTIAL_ACCESSKEY.fields_by_name['aws_secret_access_key']._options = None
_AWSCREDENTIAL.oneofs_by_name['credential']._options = None
_EXTERNALS3FILE_BUCKETREGIONKEY.fields_by_name['bucket']._options = None
_EXTERNALS3FILE_BUCKETREGIONKEY.fields_by_name['region']._options = None
_EXTERNALS3FILE_BUCKETREGIONKEY.fields_by_name['key']._options = None
_EXTERNALS3FILE.oneofs_by_name['location']._options = None
_EXTERNALS3FILE.fields_by_name['virtual_hosted_style']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/data_token.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/api/v1alpha/data_token.proto',
  package='kaskada.api.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\027com.kaskada.api.v1alphaP\001Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$kaskada/api/v1alpha/data_token.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a kaskada/api/v1alpha/shared.proto\"\xd7\x01\n\tDataToken\x12(\n\rdata_token_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x0b\x64\x61taTokenId\x12^\n\x0etable_versions\x18\x02 \x03(\x0b\x32\x31.kaskada.api.v1alpha.DataToken.TableVersionsEntryB\x04\xe2\x41\x01\x03R\rtableVersions\x1a@\n\x12TableVersionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01\"9\n\x13GetDataTokenRequest\x12\"\n\rdata_token_id\x18\x01 \x01(\tR\x0b\x64\x61taTokenId\"\xa3\x01\n\x14GetDataTokenResponse\x12=\n\ndata_token\x18\x01 \x01(\x0b\x32\x1e.kaskada.api.v1alpha.DataTokenR\tdataToken\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails2\xa8\x01\n\x10\x44\x61taTokenService\x12\x93\x01\n\x0cGetDataToken\x12(.kaskada.api.v1alpha.GetDataTokenRequest\x1a).kaskada.api.v1alpha.GetDataTokenResponse\".\x82\xd3\xe4\x93\x02(\x12&/v1alpha/data_tokens/{data_token_id=*}BV\n\x17\x63om.kaskada.api.v1alphaP\x01Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alphab\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,kaskada_dot_api_dot_v1alpha_dot_shared__pb2.DESCRIPTOR,])




_DATATOKEN_TABLEVERSIONSENTRY = _descriptor.Descriptor(
  name='TableVersionsEntry',
  full_name='kaskada.api.v1alpha.DataToken.TableVersionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='kaskada.api.v1alpha.DataToken.TableVersionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='kaskada.api.v1alpha.DataToken.TableVersionsEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=374,
)

_DATATOKEN = _descriptor.Descriptor(
  name='DataToken',
  full_name='kaskada.api.v1alpha.DataToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_token_id', full_name='kaskada.api.v1alpha.DataToken.data_token_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='dataTokenId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table_versions', full_name='kaskada.api.v1alpha.DataToken.table_versions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='tableVersions', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DATATOKEN_TABLEVERSIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=374,
)


_GETDATATOKENREQUEST = _descriptor.Descriptor(
  name='GetDataTokenRequest',
  full_name='kaskada.api.v1alpha.GetDataTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_token_id', full_name='kaskada.api.v1alpha.GetDataTokenRequest.data_token_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataTokenId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=376,
  serialized_end=433,
)


_GETDATATOKENRESPONSE = _descriptor.Descriptor(
  name='GetDataTokenResponse',
  full_name='kaskada.api.v1alpha.GetDataTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_token', full_name='kaskada.api.v1alpha.GetDataTokenResponse.data_token', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.GetDataTokenResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=436,
  serialized_end=599,
)

_DATATOKEN_TABLEVERSIONSENTRY.containing_type = _DATATOKEN
_DATATOKEN.fields_by_name['table_versions'].message_type = _DATATOKEN_TABLEVERSIONSENTRY
_GETDATATOKENRESPONSE.fields_by_name['data_token'].message_type = _DATATOKEN
_GETDATATOKENRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
DESCRIPTOR.message_types_by_name['DataToken'] = _DATATOKEN
DESCRIPTOR.message_types_by_name['GetDataTokenRequest'] = _GETDATATOKENREQUEST
DESCRIPTOR.message_types_by_name['GetDataTokenResponse'] = _GETDATATOKENRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataToken = _reflection.GeneratedProtocolMessageType('DataToken', (_message.Message,), {

  'TableVersionsEntry' : _reflection.GeneratedProtocolMessageType('TableVersionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATATOKEN_TABLEVERSIONSENTRY,
    '__module__' : 'kaskada.api.v1alpha.data_token_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DataToken.TableVersionsEntry)
    })
  ,
  'DESCRIPTOR' : _DATATOKEN,
  '__module__' : 'kaskada.api.v1alpha.data_token_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DataToken)
  })
_sym_db.RegisterMessage(DataToken)
_sym_db.RegisterMessage(DataToken.TableVersionsEntry)

GetDataTokenRequest = _reflection.GeneratedProtocolMessageType('GetDataTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATATOKENREQUEST,
  '__module__' : 'kaskada.api.v1alpha.data_token_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetDataTokenRequest)
  })
_sym_db.RegisterMessage(GetDataTokenRequest)

GetDataTokenResponse = _reflection.GeneratedProtocolMessageType('GetDataTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATATOKENRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.data_token_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetDataTokenResponse)
  })
_sym_db.RegisterMessage(GetDataTokenResponse)


DESCRIPTOR._options = None
_DATATOKEN_TABLEVERSIONSENTRY._options = None
_DATATOKEN.fields_by_name['data_token_id']._options = None
_DATATOKEN.fields_by_name['table_versions']._options = None

_DATATOKENSERVICE = _descriptor.ServiceDescriptor(
  name='DataTokenService',
  full_name='kaskada.api.v1alpha.DataTokenService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=602,
  serialized_end=770,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetDataToken',
    full_name='kaskada.api.v1alpha.DataTokenService.GetDataToken',
    index=0,
    containing_service=None,
    input_type=_GETDATATOKENREQUEST,
    output_type=_GETDATATOKENRESPONSE,
    serialized_options=b'\202\323\344\223\002(\022&/v1alpha/data_tokens/{data_token_id=*}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATATOKENSERVICE)

DESCRIPTOR.services_by_name['DataTokenService'] = _DATATOKENSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/compute.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2
from kaskada.fenl.v1alpha import schema_pb2 as kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2
from kaskada.prepare.v1alpha import slice_pb2 as kaskada_dot_prepare_dot_v1alpha_dot_slice__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/api/v1alpha/compute.proto',
  package='kaskada.api.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\027com.kaskada.api.v1alphaP\001Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!kaskada/api/v1alpha/compute.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a kaskada/api/v1alpha/shared.proto\x1a!kaskada/fenl/v1alpha/schema.proto\x1a#kaskada/prepare/v1alpha/slice.proto\x1a\x17validate/validate.proto\"\xab\x02\n\tWithTable\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x16\n\x06\x65ntity\x18\x02 \x01(\tR\x06\x65ntity\x12\x12\n\x04time\x18\x03 \x01(\tR\x04time\x12%\n\rparquet_bytes\x18\x04 \x01(\x0cH\x00R\x0cparquetBytes\x12#\n\x0cparquet_path\x18\x05 \x01(\tH\x00R\x0bparquetPath\x12L\n\x0bjson_values\x18\x06 \x01(\x0b\x32).kaskada.api.v1alpha.WithTable.JSONValuesH\x00R\njsonValues\x1a<\n\nJSONValues\x12\x16\n\x06schema\x18\x01 \x01(\tR\x06schema\x12\x16\n\x06values\x18\x02 \x03(\tR\x06valuesB\x06\n\x04\x64\x61ta\">\n\x08WithView\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1e\n\nexpression\x18\x02 \x01(\tR\nexpression\">\n\x0e\x41nalyzeRequest\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x12\x16\n\x06isView\x18\x02 \x01(\x08R\x06isView\"\xdb\x01\n\x0f\x41nalyzeResponse\x12?\n\x0bresult_type\x18\x01 \x01(\x0b\x32\x1e.kaskada.fenl.v1alpha.DataTypeR\nresultType\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\x12\x39\n\x08\x61nalysis\x18\x03 \x01(\x0b\x32\x1d.kaskada.api.v1alpha.AnalysisR\x08\x61nalysis\"\xd8\x08\n\x0cQueryRequest\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x12?\n\x0bwith_tables\x18\x02 \x03(\x0b\x32\x1e.kaskada.api.v1alpha.WithTableR\nwithTables\x12<\n\nwith_views\x18\x03 \x03(\x0b\x32\x1d.kaskada.api.v1alpha.WithViewR\twithViews\x12J\n\x0bjson_values\x18\x04 \x01(\x0b\x32\'.kaskada.api.v1alpha.QueryRequest.EmptyH\x00R\njsonValues\x12\x43\n\x07parquet\x18\x05 \x01(\x0b\x32\'.kaskada.api.v1alpha.QueryRequest.EmptyH\x00R\x07parquet\x12T\n\nredis_bulk\x18\x06 \x01(\x0b\x32\x33.kaskada.api.v1alpha.QueryRequest.RedisBulkResponseH\x00R\tredisBulk\x12G\n\tredis_a_i\x18\x08 \x01(\x0b\x32).kaskada.api.v1alpha.QueryRequest.RedisAIH\x00R\x07redisAI\x12\"\n\rdata_token_id\x18\x07 \x01(\tR\x0b\x64\x61taTokenId\x12Y\n\x0fresult_behavior\x18\t \x01(\x0e\x32\x30.kaskada.api.v1alpha.QueryRequest.ResultBehaviorR\x0eresultBehavior\x12@\n\x06limits\x18\n \x01(\x0b\x32(.kaskada.api.v1alpha.QueryRequest.LimitsR\x06limits\x12!\n\x0cresume_token\x18\x0b \x01(\tR\x0bresumeToken\x12;\n\x05slice\x18\x0c \x01(\x0b\x32%.kaskada.prepare.v1alpha.SliceRequestR\x05slice\x12\x17\n\x07\x64ry_run\x18\r \x01(\x08R\x06\x64ryRun\x1a\x07\n\x05\x45mpty\x1a+\n\x06Limits\x12!\n\x0cpreview_rows\x18\x01 \x01(\x03R\x0bpreviewRows\x1a)\n\x11RedisBulkResponse\x12\x14\n\x05shape\x18\x01 \x03(\x05R\x05shape\x1a\x62\n\x07RedisAI\x12\x19\n\x02\x64\x62\x18\x01 \x01(\x05\x42\t\xfa\x42\x06\x1a\x04\x18\x0f(\x00R\x02\x64\x62\x12\x1b\n\x04host\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04host\x12\x1f\n\x04port\x18\x03 \x01(\x05\x42\x0b\xfa\x42\x08\x1a\x06\x18\xff\xff\x03 \x00R\x04port\"u\n\x0eResultBehavior\x12\x1f\n\x1bRESULT_BEHAVIOR_UNSPECIFIED\x10\x00\x12\x1f\n\x1bRESULT_BEHAVIOR_ALL_RESULTS\x10\x01\x12!\n\x1dRESULT_BEHAVIOR_FINAL_RESULTS\x10\x02\x42\r\n\x0bresponse_as\"\x8c\x06\n\rQueryResponse\x12P\n\x0bjson_values\x18\x02 \x01(\x0b\x32-.kaskada.api.v1alpha.QueryResponse.JSONValuesH\x00R\njsonValues\x12\x46\n\x07parquet\x18\x03 \x01(\x0b\x32*.kaskada.api.v1alpha.QueryResponse.ParquetH\x00R\x07parquet\x12M\n\nredis_bulk\x18\x04 \x01(\x0b\x32,.kaskada.api.v1alpha.QueryResponse.RedisBulkH\x00R\tredisBulk\x12H\n\tredis_a_i\x18\x06 \x01(\x0b\x32*.kaskada.api.v1alpha.QueryResponse.RedisAIH\x00R\x07redisAI\x12\"\n\rdata_token_id\x18\x05 \x01(\tR\x0b\x64\x61taTokenId\x12L\n\x0frequest_details\x18\x07 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\x12*\n\x11next_resume_token\x18\x08 \x01(\tR\x0fnextResumeToken\x12\x39\n\x08\x61nalysis\x18\t \x01(\x0b\x32\x1d.kaskada.api.v1alpha.AnalysisR\x08\x61nalysis\x12\x34\n\x06schema\x18\n \x01(\x0b\x32\x1c.kaskada.fenl.v1alpha.SchemaR\x06schema\x12;\n\x05slice\x18\x0b \x01(\x0b\x32%.kaskada.prepare.v1alpha.SliceRequestR\x05slice\x1a&\n\nJSONValues\x12\x18\n\x07results\x18\x01 \x03(\tR\x07results\x1a\x1d\n\x07Parquet\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x1a\x1f\n\tRedisBulk\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x1a\t\n\x07RedisAIB\t\n\x07results2\xfe\x01\n\x0e\x43omputeService\x12y\n\x07\x41nalyze\x12#.kaskada.api.v1alpha.AnalyzeRequest\x1a$.kaskada.api.v1alpha.AnalyzeResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1alpha/compute/analyze:\x01*\x12q\n\x05Query\x12!.kaskada.api.v1alpha.QueryRequest\x1a\".kaskada.api.v1alpha.QueryResponse\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/v1alpha/compute/query:\x01*BV\n\x17\x63om.kaskada.api.v1alphaP\x01Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alphab\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,kaskada_dot_api_dot_v1alpha_dot_shared__pb2.DESCRIPTOR,kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2.DESCRIPTOR,kaskada_dot_prepare_dot_v1alpha_dot_slice__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_QUERYREQUEST_RESULTBEHAVIOR = _descriptor.EnumDescriptor(
  name='ResultBehavior',
  full_name='kaskada.api.v1alpha.QueryRequest.ResultBehavior',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESULT_BEHAVIOR_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESULT_BEHAVIOR_ALL_RESULTS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESULT_BEHAVIOR_FINAL_RESULTS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1852,
  serialized_end=1969,
)
_sym_db.RegisterEnumDescriptor(_QUERYREQUEST_RESULTBEHAVIOR)


_WITHTABLE_JSONVALUES = _descriptor.Descriptor(
  name='JSONValues',
  full_name='kaskada.api.v1alpha.WithTable.JSONValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='schema', full_name='kaskada.api.v1alpha.WithTable.JSONValues.schema', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='schema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='kaskada.api.v1alpha.WithTable.JSONValues.values', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='values', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=511,
)

_WITHTABLE = _descriptor.Descriptor(
  name='WithTable',
  full_name='kaskada.api.v1alpha.WithTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='kaskada.api.v1alpha.WithTable.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entity', full_name='kaskada.api.v1alpha.WithTable.entity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entity', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='kaskada.api.v1alpha.WithTable.time', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='time', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parquet_bytes', full_name='kaskada.api.v1alpha.WithTable.parquet_bytes', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='parquetBytes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parquet_path', full_name='kaskada.api.v1alpha.WithTable.parquet_path', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='parquetPath', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json_values', full_name='kaskada.api.v1alpha.WithTable.json_values', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jsonValues', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_WITHTABLE_JSONVALUES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='kaskada.api.v1alpha.WithTable.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=220,
  serialized_end=519,
)


_WITHVIEW = _descriptor.Descriptor(
  name='WithView',
  full_name='kaskada.api.v1alpha.WithView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='kaskada.api.v1alpha.WithView.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expression', full_name='kaskada.api.v1alpha.WithView.expression', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='expression', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=521,
  serialized_end=583,
)


_ANALYZEREQUEST = _descriptor.Descriptor(
  name='AnalyzeRequest',
  full_name='kaskada.api.v1alpha.AnalyzeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='kaskada.api.v1alpha.AnalyzeRequest.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isView', full_name='kaskada.api.v1alpha.AnalyzeRequest.isView', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isView', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=585,
  serialized_end=647,
)


_ANALYZERESPONSE = _descriptor.Descriptor(
  name='AnalyzeResponse',
  full_name='kaskada.api.v1alpha.AnalyzeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result_type', full_name='kaskada.api.v1alpha.AnalyzeResponse.result_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resultType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.AnalyzeResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='analysis', full_name='kaskada.api.v1alpha.AnalyzeResponse.analysis', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='analysis', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=650,
  serialized_end=869,
)


_QUERYREQUEST_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='kaskada.api.v1alpha.QueryRequest.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1655,
  serialized_end=1662,
)

_QUERYREQUEST_LIMITS = _descriptor.Descriptor(
  name='Limits',
  full_name='kaskada.api.v1alpha.QueryRequest.Limits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preview_rows', full_name='kaskada.api.v1alpha.QueryRequest.Limits.preview_rows', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='previewRows', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1664,
  serialized_end=1707,
)

_QUERYREQUEST_REDISBULKRESPONSE = _descriptor.Descriptor(
  name='RedisBulkResponse',
  full_name='kaskada.api.v1alpha.QueryRequest.RedisBulkResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shape', full_name='kaskada.api.v1alpha.QueryRequest.RedisBulkResponse.shape', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='shape', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1709,
  serialized_end=1750,
)

_QUERYREQUEST_REDISAI = _descriptor.Descriptor(
  name='RedisAI',
  full_name='kaskada.api.v1alpha.QueryRequest.RedisAI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='db', full_name='kaskada.api.v1alpha.QueryRequest.RedisAI.db', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006\032\004\030\017(\000', json_name='db', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='kaskada.api.v1alpha.QueryRequest.RedisAI.host', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='host', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='kaskada.api.v1alpha.QueryRequest.RedisAI.port', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010\032\006\030\377\377\003 \000', json_name='port', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1752,
  serialized_end=1850,
)

_QUERYREQUEST = _descriptor.Descriptor(
  name='QueryRequest',
  full_name='kaskada.api.v1alpha.QueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='kaskada.api.v1alpha.QueryRequest.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_tables', full_name='kaskada.api.v1alpha.QueryRequest.with_tables', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='withTables', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_views', full_name='kaskada.api.v1alpha.QueryRequest.with_views', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='withViews', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json_values', full_name='kaskada.api.v1alpha.QueryRequest.json_values', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jsonValues', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parquet', full_name='kaskada.api.v1alpha.QueryRequest.parquet', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='parquet', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redis_bulk', full_name='kaskada.api.v1alpha.QueryRequest.redis_bulk', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='redisBulk', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redis_a_i', full_name='kaskada.api.v1alpha.QueryRequest.redis_a_i', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='redisAI', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_token_id', full_name='kaskada.api.v1alpha.QueryRequest.data_token_id', index=7,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataTokenId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_behavior', full_name='kaskada.api.v1alpha.QueryRequest.result_behavior', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resultBehavior', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limits', full_name='kaskada.api.v1alpha.QueryRequest.limits', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limits', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resume_token', full_name='kaskada.api.v1alpha.QueryRequest.resume_token', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resumeToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slice', full_name='kaskada.api.v1alpha.QueryRequest.slice', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='slice', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dry_run', full_name='kaskada.api.v1alpha.QueryRequest.dry_run', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dryRun', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUERYREQUEST_EMPTY, _QUERYREQUEST_LIMITS, _QUERYREQUEST_REDISBULKRESPONSE, _QUERYREQUEST_REDISAI, ],
  enum_types=[
    _QUERYREQUEST_RESULTBEHAVIOR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response_as', full_name='kaskada.api.v1alpha.QueryRequest.response_as',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=872,
  serialized_end=1984,
)


_QUERYRESPONSE_JSONVALUES = _descriptor.Descriptor(
  name='JSONValues',
  full_name='kaskada.api.v1alpha.QueryResponse.JSONValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='kaskada.api.v1alpha.QueryResponse.JSONValues.results', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='results', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2643,
  serialized_end=2681,
)

_QUERYRESPONSE_PARQUET = _descriptor.Descriptor(
  name='Parquet',
  full_name='kaskada.api.v1alpha.QueryResponse.Parquet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='kaskada.api.v1alpha.QueryResponse.Parquet.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='path', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2683,
  serialized_end=2712,
)

_QUERYRESPONSE_REDISBULK = _descriptor.Descriptor(
  name='RedisBulk',
  full_name='kaskada.api.v1alpha.QueryResponse.RedisBulk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='kaskada.api.v1alpha.QueryResponse.RedisBulk.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='path', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2714,
  serialized_end=2745,
)

_QUERYRESPONSE_REDISAI = _descriptor.Descriptor(
  name='RedisAI',
  full_name='kaskada.api.v1alpha.QueryResponse.RedisAI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1752,
  serialized_end=1761,
)

_QUERYRESPONSE = _descriptor.Descriptor(
  name='QueryResponse',
  full_name='kaskada.api.v1alpha.QueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='json_values', full_name='kaskada.api.v1alpha.QueryResponse.json_values', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jsonValues', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parquet', full_name='kaskada.api.v1alpha.QueryResponse.parquet', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='parquet', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redis_bulk', full_name='kaskada.api.v1alpha.QueryResponse.redis_bulk', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='redisBulk', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redis_a_i', full_name='kaskada.api.v1alpha.QueryResponse.redis_a_i', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='redisAI', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_token_id', full_name='kaskada.api.v1alpha.QueryResponse.data_token_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataTokenId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.QueryResponse.request_details', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_resume_token', full_name='kaskada.api.v1alpha.QueryResponse.next_resume_token', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nextResumeToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='analysis', full_name='kaskada.api.v1alpha.QueryResponse.analysis', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='analysis', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='kaskada.api.v1alpha.QueryResponse.schema', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='schema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slice', full_name='kaskada.api.v1alpha.QueryResponse.slice', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='slice', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUERYRESPONSE_JSONVALUES, _QUERYRESPONSE_PARQUET, _QUERYRESPONSE_REDISBULK, _QUERYRESPONSE_REDISAI, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='results', full_name='kaskada.api.v1alpha.QueryResponse.results',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1987,
  serialized_end=2767,
)

_WITHTABLE_JSONVALUES.containing_type = _WITHTABLE
_WITHTABLE.fields_by_name['json_values'].message_type = _WITHTABLE_JSONVALUES
_WITHTABLE.oneofs_by_name['data'].fields.append(
  _WITHTABLE.fields_by_name['parquet_bytes'])
_WITHTABLE.fields_by_name['parquet_bytes'].containing_oneof = _WITHTABLE.oneofs_by_name['data']
_WITHTABLE.oneofs_by_name['data'].fields.append(
  _WITHTABLE.fields_by_name['parquet_path'])
_WITHTABLE.fields_by_name['parquet_path'].containing_oneof = _WITHTABLE.oneofs_by_name['data']
_WITHTABLE.oneofs_by_name['data'].fields.append(
  _WITHTABLE.fields_by_name['json_values'])
_WITHTABLE.fields_by_name['json_values'].containing_oneof = _WITHTABLE.oneofs_by_name['data']
_ANALYZERESPONSE.fields_by_name['result_type'].message_type = kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2._DATATYPE
_ANALYZERESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_ANALYZERESPONSE.fields_by_name['analysis'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._ANALYSIS
_QUERYREQUEST_EMPTY.containing_type = _QUERYREQUEST
_QUERYREQUEST_LIMITS.containing_type = _QUERYREQUEST
_QUERYREQUEST_REDISBULKRESPONSE.containing_type = _QUERYREQUEST
_QUERYREQUEST_REDISAI.containing_type = _QUERYREQUEST
_QUERYREQUEST.fields_by_name['with_tables'].message_type = _WITHTABLE
_QUERYREQUEST.fields_by_name['with_views'].message_type = _WITHVIEW
_QUERYREQUEST.fields_by_name['json_values'].message_type = _QUERYREQUEST_EMPTY
_QUERYREQUEST.fields_by_name['parquet'].message_type = _QUERYREQUEST_EMPTY
_QUERYREQUEST.fields_by_name['redis_bulk'].message_type = _QUERYREQUEST_REDISBULKRESPONSE
_QUERYREQUEST.fields_by_name['redis_a_i'].message_type = _QUERYREQUEST_REDISAI
_QUERYREQUEST.fields_by_name['result_behavior'].enum_type = _QUERYREQUEST_RESULTBEHAVIOR
_QUERYREQUEST.fields_by_name['limits'].message_type = _QUERYREQUEST_LIMITS
_QUERYREQUEST.fields_by_name['slice'].message_type = kaskada_dot_prepare_dot_v1alpha_dot_slice__pb2._SLICEREQUEST
_QUERYREQUEST_RESULTBEHAVIOR.containing_type = _QUERYREQUEST
_QUERYREQUEST.oneofs_by_name['response_as'].fields.append(
  _QUERYREQUEST.fields_by_name['json_values'])
_QUERYREQUEST.fields_by_name['json_values'].containing_oneof = _QUERYREQUEST.oneofs_by_name['response_as']
_QUERYREQUEST.oneofs_by_name['response_as'].fields.append(
  _QUERYREQUEST.fields_by_name['parquet'])
_QUERYREQUEST.fields_by_name['parquet'].containing_oneof = _QUERYREQUEST.oneofs_by_name['response_as']
_QUERYREQUEST.oneofs_by_name['response_as'].fields.append(
  _QUERYREQUEST.fields_by_name['redis_bulk'])
_QUERYREQUEST.fields_by_name['redis_bulk'].containing_oneof = _QUERYREQUEST.oneofs_by_name['response_as']
_QUERYREQUEST.oneofs_by_name['response_as'].fields.append(
  _QUERYREQUEST.fields_by_name['redis_a_i'])
_QUERYREQUEST.fields_by_name['redis_a_i'].containing_oneof = _QUERYREQUEST.oneofs_by_name['response_as']
_QUERYRESPONSE_JSONVALUES.containing_type = _QUERYRESPONSE
_QUERYRESPONSE_PARQUET.containing_type = _QUERYRESPONSE
_QUERYRESPONSE_REDISBULK.containing_type = _QUERYRESPONSE
_QUERYRESPONSE_REDISAI.containing_type = _QUERYRESPONSE
_QUERYRESPONSE.fields_by_name['json_values'].message_type = _QUERYRESPONSE_JSONVALUES
_QUERYRESPONSE.fields_by_name['parquet'].message_type = _QUERYRESPONSE_PARQUET
_QUERYRESPONSE.fields_by_name['redis_bulk'].message_type = _QUERYRESPONSE_REDISBULK
_QUERYRESPONSE.fields_by_name['redis_a_i'].message_type = _QUERYRESPONSE_REDISAI
_QUERYRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_QUERYRESPONSE.fields_by_name['analysis'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._ANALYSIS
_QUERYRESPONSE.fields_by_name['schema'].message_type = kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2._SCHEMA
_QUERYRESPONSE.fields_by_name['slice'].message_type = kaskada_dot_prepare_dot_v1alpha_dot_slice__pb2._SLICEREQUEST
_QUERYRESPONSE.oneofs_by_name['results'].fields.append(
  _QUERYRESPONSE.fields_by_name['json_values'])
_QUERYRESPONSE.fields_by_name['json_values'].containing_oneof = _QUERYRESPONSE.oneofs_by_name['results']
_QUERYRESPONSE.oneofs_by_name['results'].fields.append(
  _QUERYRESPONSE.fields_by_name['parquet'])
_QUERYRESPONSE.fields_by_name['parquet'].containing_oneof = _QUERYRESPONSE.oneofs_by_name['results']
_QUERYRESPONSE.oneofs_by_name['results'].fields.append(
  _QUERYRESPONSE.fields_by_name['redis_bulk'])
_QUERYRESPONSE.fields_by_name['redis_bulk'].containing_oneof = _QUERYRESPONSE.oneofs_by_name['results']
_QUERYRESPONSE.oneofs_by_name['results'].fields.append(
  _QUERYRESPONSE.fields_by_name['redis_a_i'])
_QUERYRESPONSE.fields_by_name['redis_a_i'].containing_oneof = _QUERYRESPONSE.oneofs_by_name['results']
DESCRIPTOR.message_types_by_name['WithTable'] = _WITHTABLE
DESCRIPTOR.message_types_by_name['WithView'] = _WITHVIEW
DESCRIPTOR.message_types_by_name['AnalyzeRequest'] = _ANALYZEREQUEST
DESCRIPTOR.message_types_by_name['AnalyzeResponse'] = _ANALYZERESPONSE
DESCRIPTOR.message_types_by_name['QueryRequest'] = _QUERYREQUEST
DESCRIPTOR.message_types_by_name['QueryResponse'] = _QUERYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WithTable = _reflection.GeneratedProtocolMessageType('WithTable', (_message.Message,), {

  'JSONValues' : _reflection.GeneratedProtocolMessageType('JSONValues', (_message.Message,), {
    'DESCRIPTOR' : _WITHTABLE_JSONVALUES,
    '__module__' : 'kaskada.api.v1alpha.compute_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.WithTable.JSONValues)
    })
  ,
  'DESCRIPTOR' : _WITHTABLE,
  '__module__' : 'kaskada.api.v1alpha.compute_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.WithTable)
  })
_sym_db.RegisterMessage(WithTable)
_sym_db.RegisterMessage(WithTable.JSONValues)

WithView = _reflection.GeneratedProtocolMessageType('WithView', (_message.Message,), {
  'DESCRIPTOR' : _WITHVIEW,
  '__module__' : 'kaskada.api.v1alpha.compute_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.WithView)
  })
_sym_db.RegisterMessage(WithView)

AnalyzeRequest = _reflection.GeneratedProtocolMessageType('AnalyzeRequest', (_message.Message,), {
  'DESCRIPTOR' : _ANALYZEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.compute_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.AnalyzeRequest)
  })
_sym_db.RegisterMessage(AnalyzeRequest)

AnalyzeResponse = _reflection.GeneratedProtocolMessageType('AnalyzeResponse', (_message.Message,), {
  'DESCRIPTOR' : _ANALYZERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.compute_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.AnalyzeResponse)
  })
_sym_db.RegisterMessage(AnalyzeResponse)

QueryRequest = _reflection.GeneratedProtocolMessageType('QueryRequest', (_message.Message,), {

  'Empty' : _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
    'DESCRIPTOR' : _QUERYREQUEST_EMPTY,
    '__module__' : 'kaskada.api.v1alpha.compute_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.QueryRequest.Empty)
    })
  ,

  'Limits' : _reflection.GeneratedProtocolMessageType('Limits', (_message.Message,), {
    'DESCRIPTOR' : _QUERYREQUEST_LIMITS,
    '__module__' : 'kaskada.api.v1alpha.compute_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.QueryRequest.Limits)
    })
  ,

  'RedisBulkResponse' : _reflection.GeneratedProtocolMessageType('RedisBulkResponse', (_message.Message,), {
    'DESCRIPTOR' : _QUERYREQUEST_REDISBULKRESPONSE,
    '__module__' : 'kaskada.api.v1alpha.compute_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.QueryRequest.RedisBulkResponse)
    })
  ,

  'RedisAI' : _reflection.GeneratedProtocolMessageType('RedisAI', (_message.Message,), {
    'DESCRIPTOR' : _QUERYREQUEST_REDISAI,
    '__module__' : 'kaskada.api.v1alpha.compute_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.QueryRequest.RedisAI)
    })
  ,
  'DESCRIPTOR' : _QUERYREQUEST,
  '__module__' : 'kaskada.api.v1alpha.compute_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.QueryRequest)
  })
_sym_db.RegisterMessage(QueryRequest)
_sym_db.RegisterMessage(QueryRequest.Empty)
_sym_db.RegisterMessage(QueryRequest.Limits)
_sym_db.RegisterMessage(QueryRequest.RedisBulkResponse)
_sym_db.RegisterMessage(QueryRequest.RedisAI)

QueryResponse = _reflection.GeneratedProtocolMessageType('QueryResponse', (_message.Message,), {

  'JSONValues' : _reflection.GeneratedProtocolMessageType('JSONValues', (_message.Message,), {
    'DESCRIPTOR' : _QUERYRESPONSE_JSONVALUES,
    '__module__' : 'kaskada.api.v1alpha.compute_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.QueryResponse.JSONValues)
    })
  ,

  'Parquet' : _reflection.GeneratedProtocolMessageType('Parquet', (_message.Message,), {
    'DESCRIPTOR' : _QUERYRESPONSE_PARQUET,
    '__module__' : 'kaskada.api.v1alpha.compute_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.QueryResponse.Parquet)
    })
  ,

  'RedisBulk' : _reflection.GeneratedProtocolMessageType('RedisBulk', (_message.Message,), {
    'DESCRIPTOR' : _QUERYRESPONSE_REDISBULK,
    '__module__' : 'kaskada.api.v1alpha.compute_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.QueryResponse.RedisBulk)
    })
  ,

  'RedisAI' : _reflection.GeneratedProtocolMessageType('RedisAI', (_message.Message,), {
    'DESCRIPTOR' : _QUERYRESPONSE_REDISAI,
    '__module__' : 'kaskada.api.v1alpha.compute_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.QueryResponse.RedisAI)
    })
  ,
  'DESCRIPTOR' : _QUERYRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.compute_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.QueryResponse)
  })
_sym_db.RegisterMessage(QueryResponse)
_sym_db.RegisterMessage(QueryResponse.JSONValues)
_sym_db.RegisterMessage(QueryResponse.Parquet)
_sym_db.RegisterMessage(QueryResponse.RedisBulk)
_sym_db.RegisterMessage(QueryResponse.RedisAI)


DESCRIPTOR._options = None
_QUERYREQUEST_REDISAI.fields_by_name['db']._options = None
_QUERYREQUEST_REDISAI.fields_by_name['host']._options = None
_QUERYREQUEST_REDISAI.fields_by_name['port']._options = None

_COMPUTESERVICE = _descriptor.ServiceDescriptor(
  name='ComputeService',
  full_name='kaskada.api.v1alpha.ComputeService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2770,
  serialized_end=3024,
  methods=[
  _descriptor.MethodDescriptor(
    name='Analyze',
    full_name='kaskada.api.v1alpha.ComputeService.Analyze',
    index=0,
    containing_service=None,
    input_type=_ANALYZEREQUEST,
    output_type=_ANALYZERESPONSE,
    serialized_options=b'\202\323\344\223\002\035\"\030/v1alpha/compute/analyze:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Query',
    full_name='kaskada.api.v1alpha.ComputeService.Query',
    index=1,
    containing_service=None,
    input_type=_QUERYREQUEST,
    output_type=_QUERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\"\026/v1alpha/compute/query:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_COMPUTESERVICE)

DESCRIPTOR.services_by_name['ComputeService'] = _COMPUTESERVICE

# @@protoc_insertion_point(module_scope)
